@@ -19,6 +19,7 @@ class SeismicStoreAPI(API):
 
     def search(
         self,
+        mode: str = "seismic_store",
         *,
         id: Union[int, None] = None,
         external_id: MaybeString = None,
@@ -32,14 +33,16 @@ class SeismicStoreAPI(API):
     ) -> Iterable[SeismicStore]:
         """Search for seismic stores.
 
-        Can search by id, name, or substring or name. 
+        Can search all seismic stores included in surveys or directly search seismic stores,
+        specified by id, external_id, name, or substrings of external_id or name. 
         Only one search method should be specified. The behaviour when multiple are specified is undefined.
 
         Args:
-            id (int|None): Seismic store id
-            external_id (str|None): Seismic store external id. NOT IMPLEMENTED
+            mode (str): One of "survey" or "seismic_store".
+            id (int|None): Id to search by
+            external_id (str|None): External id to search by. NOT IMPLEMENTED
             external_id_substring (str|None): Substring of external id to search by. NOT IMPLEMENTED
-            name (str|None): Seismic store name
+            name (str|None): Name to search by
             name_substring (str|None): Substring of name to search by
             get_all (bool): Whether to instead retrieve all visible seismic stores. Equivalent to list().
             include_file_info (bool): If true, the response will include information on the source file.
@@ -50,19 +53,20 @@ class SeismicStoreAPI(API):
             Iterable[SeismicStore]: The list of matching seismic stores
         """
         if get_all:
-            req = SearchSeismicStoresRequest(
-                include_file_info=include_file_info,
-                include_headers=include_headers,
-                include_volume_definitions=include_volume_definitions,
-            )
+            req = SearchSeismicStoresRequest()
         else:
             spec = get_search_spec(id, external_id, external_id_substring, name, name_substring)
-            req = SearchSeismicStoresRequest(
-                seismic_stores=spec,
-                include_file_info=include_file_info,
-                include_headers=include_headers,
-                include_volume_definitions=include_volume_definitions,
-            )
+            if mode == "seismic_store":
+                req = SearchSeismicStoresRequest(seismic_store=spec)
+            elif mode == "survey":
+                req = SearchSeismicStoresRequest(survey=spec)
+            else:
+                raise Exception("mode should be one of: survey, seismic_store")
+
+        req.include_file_info = include_file_info
+        req.include_headers = include_headers
+        req.include_volume_definitions = include_volume_definitions
+
         results = self.query.SearchSeismicStores(req, metadata=self.metadata)
         return [SeismicStore.from_proto(p) for p in results]
 
