@@ -1,3 +1,4 @@
+import json
 import os
 from typing import List, Mapping, Optional, Tuple, Union
 
@@ -82,14 +83,64 @@ class VolumeDef:
 
     json: str
 
-    def __init__(self, json):
-        self.json = json
+    def __init__(self, json_payload):
+        self.json = json_payload
+        self.parsed = json.loads(json_payload)
 
     def __repr__(self):
         return f"VolumeDef<{self.json}>"
 
+    @staticmethod
     def from_proto(proto) -> "VolumeDef":
-        return VolumeDef(json=proto.json)
+        return VolumeDef(json_payload=proto.json)
+
+    @staticmethod
+    def _get_method_size(method) -> int:
+        """Given a volumedef method, calculate the number of traces within it"""
+        c = 0
+        if "list" in method:
+            c += len(method["list"])
+        elif "range" in method:
+            range_ = method["range"]
+            if len(range_) == 3:
+                step = range_[2]
+            else:
+                # Accounting for negative ranges
+                if range_[0] < range_[1]:
+                    step = 1
+                else:
+                    step = -1
+            c += (range_[1] - range_[0]) // step + 1
+        else:
+            raise Exception(f"The specified method {method} was not recognized.")
+
+        return c
+
+    def count_line_traces(self) -> Mapping[int, int]:
+        """Count the number of traces by line.
+        
+        Returns:
+            Mapping[int, int]: A mapping of line number to trace count.
+        """
+        if self.parsed["version"] > 101:
+            raise Exception(
+                f'The specified volumedef version {self.parsed["version"]} is not supported by this version of the Cognite SDK.'
+            )
+        output = {}
+        for key, methods in self.parsed["lines"].items():
+            c = 0
+            for method in methods:
+                c += VolumeDef._get_method_size(method)
+            output[int(key)] = c
+        return output
+
+    def count_total_traces(self) -> int:
+        """Count the total number of traces in this volumedef."""
+        c = 0
+        traces = self.count_line_traces()
+        for val in traces.values():
+            c += val
+        return c
 
 
 class File:
@@ -375,6 +426,47 @@ class SeismicStore:
         )
 
 
+class SeismicLineRange:
+    """Represents the line range for a seismic"""
+
+    inline_min: int
+    inline_max: int
+    inline_step: int
+    crossline_min: int
+    crossline_max: int
+    crossline_step: int
+
+    def __init__(self, inline_min, inline_max, inline_step, crossline_min, crossline_max, crossline_step):
+        self.inline_min = inline_min
+        self.inline_max = inline_max
+        self.inline_step = inline_step
+        self.crossline_min = crossline_min
+        self.crossline_max = crossline_max
+        self.crossline_step = crossline_step
+
+    def __repr__(self):
+        return (
+            "SeismicLineRange<"
+            f"inline_min: {self.inline_min}, "
+            f"inline_max: {self.inline_max}, "
+            f"inline_step: {self.inline_step}, "
+            f"crossline_min: {self.crossline_min}, "
+            f"crossline_max: {self.crossline_max}, "
+            f"crossline_step: {self.crossline_step}>"
+        )
+
+    @staticmethod
+    def from_proto(proto) -> "SeismicLineRange":
+        return SeismicLineRange(
+            inline_min=proto.inline.min.value,
+            inline_max=proto.inline.max.value,
+            inline_step=proto.inline.step.value,
+            crossline_min=proto.crossline.min.value,
+            crossline_max=proto.crossline.max.value,
+            crossline_step=proto.crossline.step.value,
+        )
+
+
 class Seismic:
     """Represents a seismic, a subset of a seismic store."""
 
@@ -385,7 +477,7 @@ class Seismic:
     metadata: Mapping[str, str]
     text_header: Optional[TextHeader]
     binary_header: Optional[BinaryHeader]
-    line_range: Optional[Tuple[int, int]]
+    line_range: Optional[SeismicLineRange]
     volume_def: Optional[VolumeDef]
     partition_id: int
     seismicstore_id: Optional[int]
@@ -436,7 +528,7 @@ class Seismic:
             metadata=metadata,
             text_header=TextHeader.from_proto(proto.text_header),
             binary_header=BinaryHeader.from_proto(proto.binary_header),
-            line_range=(proto.line_range.from_line, proto.line_range.to_line),
+            line_range=SeismicLineRange.from_proto(proto.line_range),
             volume_def=VolumeDef.from_proto(proto.volume_def),
             partition_id=proto.partition_id,
             seismicstore_id=proto.seismicstore_id,
